@@ -11,7 +11,7 @@ use JSON::XS qw(decode_json encode_json);
 use Time::HiRes qw(gettimeofday time);
 use Data::Dumper;
 
-our $VERSION = "0.041";
+our $VERSION = "0.042";
 
 my %INFO_ROUTES = (
     version => '/version',
@@ -265,6 +265,17 @@ sub multiget {
     my @result = ();
     foreach my $url (@$multiget_urls) {
         my $rows = $self->_multiget_tiny($url->{url});
+        if ($self->{last_error}) {
+            if ($self->{last_error}->{type} eq '404') {
+
+                # if some of the keys don't exists, just ignore it
+                $self->{last_error} = undef;
+
+            } else {
+                #some other error in the middle, fail the whole thing
+                return [];
+            }
+        }
         push @result, @$rows
             if ($rows and @$rows);
     }
